#[derive(Termination)]Expand description
Derives Termination.
Requires:
#[repr(u8)]- Discriminant assigned to each variation, will be used as the ExitCode
- Generic parameter as type of the “Ok” case, which must implement std::process::Termination
- The data stored in any variants must implement Display